/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "FileRandomReaderTest.h"

CFileRandomReaderTest::CFileRandomReaderTest()
{
	iFile1Open = EFalse;
	iFile2Open = EFalse;
}

CFileRandomReaderTest::~CFileRandomReaderTest()
{
	delete aFileReader1;
	delete aFileReader2;

	iLog.CloseLog();
	iLog.Close();
}

CFileRandomReaderTest *CFileRandomReaderTest::NewL()
{
	CFileRandomReaderTest *self = new (ELeave) CFileRandomReaderTest;
	CleanupStack::PushL(self);
	self->ConstructL();
   	CleanupStack::Pop(self);
   	return self;
}

void CFileRandomReaderTest::ConstructL()
{
	iLog.Connect();
	iLog.CreateLog(_L("DictLog"),
				   _L("LogFileFileRandomTest"),
				   EFileLoggingModeOverwrite);
	iLog.SetDateAndTime(EFalse, EFalse);
	iLog.WriteFormat(_L("Created log file"));

	aFileReader1 = new (ELeave) FileRandomReader;
	aFileReader2 = new (ELeave) FileRandomReader;
}

TBool CFileRandomReaderTest::StartTesting()
{
	TInt res;
	res = aFileReader1->Open(_L("c:\\system\\apps\\dict\\FileRandomReaderTestFile1"));
	if (res != KErrNone)
	{
		iLog.WriteFormat(_L("ERROR1: Can't open test file (%d)!"), res);
		return EFalse;
	}
	else
	{
		TInt size = aFileReader1->GetSize();
		if ( size != 618)
		{
			iLog.WriteFormat(_L("ERROR1: Wrong size (%d)!"), size);
			return EFalse;
		}
		iFile1Open = ETrue;
	}

	res = aFileReader2->Open(_L("c:\\system\\apps\\dict\\FileRandomReaderTestFile2"),
							 ETrue);
	if (res != KErrNone)
	{
		iLog.WriteFormat(_L("ERROR2: Can't open test file 2 (%d)!"), res);
		return EFalse;
	}
	else
	{
		TInt size = aFileReader2->GetSize();
		if ( size != 618)
		{
			iLog.WriteFormat(_L("ERROR2: Wrong size (%d)!"), size);
			return EFalse;
		}
		iFile2Open = ETrue;
	}

	iLog.WriteFormat(_L("OK: Started testing."));
	return ETrue;
}

TBool CFileRandomReaderTest::ReadByteTest()
{
	iLog.WriteFormat(_L("--- ReadByteTest ---"));
	if (!iFile1Open || !iFile2Open)
	{
		iLog.WriteFormat(_L("ERROR: Can't access test files!"));
		return EFalse;
	}

	TInt pos = 300;
	TUint8 value = 0;
	TUint8 readBack;
	for(TInt i=0; i<10; i++)
	{
		readBack = aFileReader1->ReadByte(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR1: Read back %02X instead of %02X!"),
							 readBack, value);
			return EFalse;
		}
		value++;
		pos++;
	}

	pos = 300;
	value = 0;
	for(TInt i=0; i<10; i++)
	{
		readBack = aFileReader2->ReadByte(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR2: Read back %02X instead of %02X!"),
							 readBack, value);
			return EFalse;
		}
		value++;
		pos++;
	}

	pos = 608;
	value = 0x0A;
	for(TInt i=0; i<10; i++)
	{
		readBack = aFileReader1->ReadByte(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR1: Read back %02X instead of %02X!"),
							 readBack, value);
			return EFalse;
		}
		value++;
		pos++;
	}

	pos = 608;
	value = 0x0A;
	for(TInt i=0; i<10; i++)
	{
		readBack = aFileReader2->ReadByte(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR2: Read back %02X instead of %02X!"),
							 readBack, value);
			return EFalse;
		}
		value++;
		pos++;
	}

	iLog.WriteFormat(_L("Test OK."));
	return ETrue;
}

TBool CFileRandomReaderTest::ReadWordTest()
{
	iLog.WriteFormat(_L("--- ReadWordTest ---"));
	if (!iFile1Open || !iFile2Open)
	{
		iLog.WriteFormat(_L("ERROR: Can't access test files!"));
		return EFalse;
	}

	TInt pos = 300;
	TUint16 value = 0x0100;
	TUint16 readBack;
	for(TInt i=0; i<9; i++)
	{
		readBack = aFileReader1->ReadWord(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR1: Read back %04X instead of %04X!"),
							 readBack, value);
			return EFalse;
		}
		value += 0x0101;
		pos++;
	}

	pos = 300;
	value = 0x0100;
	for(TInt i=0; i<9; i++)
	{
		readBack = aFileReader2->ReadWord(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR2: Read back %04X instead of %04X!"),
							 readBack, value);
			return EFalse;
		}
		value += 0x0101;
		pos++;
	}

	pos = 608;
	value = 0x0B0A;
	for(TInt i=0; i<9; i++)
	{
		readBack = aFileReader1->ReadWord(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR1: Read back %04X instead of %04X!"),
							 readBack, value);
			return EFalse;
		}
		value += 0x0101;
		pos++;
	}

	pos = 608;
	value = 0x0B0A;
	for(TInt i=0; i<9; i++)
	{
		readBack = aFileReader2->ReadWord(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR2: Read back %04X instead of %04X!"),
							 readBack, value);
			return EFalse;
		}
		value += 0x0101;
		pos++;
	}

	iLog.WriteFormat(_L("Test OK."));
	return ETrue;
}

TBool CFileRandomReaderTest::ReadIntTest()
{
	iLog.WriteFormat(_L("--- ReadIntTest ---"));
	if (!iFile1Open || !iFile2Open)
	{
		iLog.WriteFormat(_L("ERROR: Can't access test files!"));
		return EFalse;
	}

	TInt pos = 300;
	TInt value = 0x03020100;
	TInt readBack;
	for(TInt i=0; i<7; i++)
	{
		readBack = aFileReader1->ReadInt(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR1: Read back %d instead of %d!"),
							 readBack, value);
			return EFalse;
		}
		value += 0x01010101;
		pos++;
	}

	pos = 300;
	value = 0x03020100;
	for(TInt i=0; i<7; i++)
	{
		readBack = aFileReader2->ReadInt(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR2: Read back %d instead of %d!"),
							 readBack, value);
			return EFalse;
		}
		value += 0x01010101;
		pos++;
	}

	pos = 608;
	value = 0x0D0C0B0A;
	for(TInt i=0; i<7; i++)
	{
		readBack = aFileReader1->ReadInt(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR1: Read back %d instead of %d!"),
							 readBack, value);
			return EFalse;
		}
		value += 0x01010101;
		pos++;
	}

	pos = 608;
	value = 0x0D0C0B0A;
	for(TInt i=0; i<7; i++)
	{
		readBack = aFileReader2->ReadInt(pos);
		if (readBack != value)
		{
			iLog.WriteFormat(_L("ERROR2: Read back %d instead of %d!"),
							 readBack, value);
			return EFalse;
		}
		value += 0x01010101;
		pos++;
	}


	return ETrue;
}

TBool CFileRandomReaderTest::ReadStringTest()
{
	iLog.WriteFormat(_L("--- ReadStringTest ---"));
	if (!iFile1Open || !iFile2Open)
	{
		iLog.WriteFormat(_L("ERROR: Can't access test files!"));
		return EFalse;
	}

	TInt i, pos = 270;
	TBuf8<30> readBackString, compareString;
	_LIT8(KCompareString,"This is a test file Line 001");
	compareString.Copy(KCompareString);
	for(i=10; i>0; i--)
	{
		if (!aFileReader1->Read(readBackString, pos, 28))
		{
			iLog.WriteFormat(_L("ERROR1: Can't read at address %d!"), pos);
			return EFalse;
		}
		compareString[26] = (TUint8) ('0' + (i / 10));
		compareString[27] = (TUint8) ('0' + (i % 10));
		if (compareString.Compare(readBackString) != 0)
		{
			iLog.WriteFormat(_L("ERROR1: Error reading back string at address %d!"), pos);
			return EFalse;
		}
		pos -= 30;
	}

	pos = 270;
	for(i=10; i>0; i--)
	{
		if (!aFileReader2->Read(readBackString, pos, 28))
		{
			iLog.WriteFormat(_L("ERROR2: Can't read at address %d!"), pos);
			return EFalse;
		}
		compareString[26] = (TUint8) ('0' + (i / 10));
		compareString[27] = (TUint8) ('0' + (i % 10));
		if (compareString.Compare(readBackString) != 0)
		{
			iLog.WriteFormat(_L("ERROR2: Error reading back string at address %d!"), pos);
			return EFalse;
		}
		pos -= 30;
	}

	pos = 310;
	for(i=1; i<=10; i++)
	{
		if (!aFileReader1->Read(readBackString, pos, 28))
		{
			iLog.WriteFormat(_L("ERROR1: Can't read at address %d!"), pos);
			return EFalse;
		}
		compareString[26] = (TUint8) ('1' + (i / 10));
		compareString[27] = (TUint8) ('0' + (i % 10));
		if (compareString.Compare(readBackString) != 0)
		{
			iLog.WriteFormat(_L("ERROR1: Error reading back string at address %d!"), pos);
			return EFalse;
		}
		pos += 30;
	}

	pos = 310;
	for(i=1; i<=10; i++)
	{
		if (!aFileReader2->Read(readBackString, pos, 28))
		{
			iLog.WriteFormat(_L("ERROR2: Can't read at address %d!"), pos);
			return EFalse;
		}
		compareString[26] = (TUint8) ('1' + (i / 10));
		compareString[27] = (TUint8) ('0' + (i % 10));
		if (compareString.Compare(readBackString) != 0)
		{
			iLog.WriteFormat(_L("ERROR2: Error reading back string at address %d!"), pos);
			return EFalse;
		}
		pos += 30;
	}

	iLog.WriteFormat(_L("Test OK."));
	return ETrue;
}

TBool CFileRandomReaderTest::ReadLongStringTest()
{
	iLog.WriteFormat(_L("--- ReadLongStringTest ---"));
	if (!iFile1Open || !iFile2Open)
	{
		iLog.WriteFormat(_L("ERROR: Can't access test files!"));
		return EFalse;
	}

	TBuf8<300> readBackString;
	if (!aFileReader1->Read(readBackString, 0, 300))
	{
		iLog.WriteFormat(_L("ERROR1: Can't read long string!"));
		return EFalse;
	}
	iLog.WriteFormat(_L("1. Length = %d"), readBackString.Length());
	iLog.WriteFormat(readBackString);
	iLog.WriteFormat(readBackString.Mid(150));

	if (!aFileReader1->Read(readBackString, 310, 300))
	{
		iLog.WriteFormat(_L("ERROR1: Can't read long string!"));
		return EFalse;
	}
	iLog.WriteFormat(_L("2. Length = %d"), readBackString.Length());
	iLog.WriteFormat(readBackString);
	iLog.WriteFormat(readBackString.Mid(150));

	if (!aFileReader2->Read(readBackString, 0, 300))
	{
		iLog.WriteFormat(_L("ERROR1: Can't read long string!"));
		return EFalse;
	}
	iLog.WriteFormat(_L("3. Length = %d"), readBackString.Length());
	iLog.WriteFormat(readBackString);
	iLog.WriteFormat(readBackString.Mid(150));

	if (!aFileReader2->Read(readBackString, 310, 300))
	{
		iLog.WriteFormat(_L("ERROR1: Can't read long string!"));
		return EFalse;
	}
	iLog.WriteFormat(_L("4. Length = %d"), readBackString.Length());
	iLog.WriteFormat(readBackString);
	iLog.WriteFormat(readBackString.Mid(150));

	iLog.WriteFormat(_L("Test OK."));
	return ETrue;
}