/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __DICT_APPUI_H__
#define __DICT_APPUI_H__

#include <aknViewAppUi.h>

class CDictSearchView;
class CDictResultsListView;
class CDictMeaningView;
class CDocumentHandler;
class CDictFactory;

/**
  An instance of CDictAppUi is the user interface part of the
  AVKON application framework. It implements the interconnection between the
  dict engine and the User Interface. It is responsible for switching between
  the different views. Derived from CAknViewAppUi.
  */
class CDictAppUi : public CAknViewAppUi
	{
public:
/**
  Constructor.
  */
	CDictAppUi();

/**
  Destructor.
  */
	~CDictAppUi();

/**
  Performs the second phase construction of a CDictAppUi object.
  This needs to be public due to the way the framework constructs the AppUi.
  */
	void ConstructL();

public: // from CAknAppUi
/**
  Handles user menu selections. (from CAknAppUi)
  @param aCommand The enumerated code for the option selected.
  */
	void HandleCommandL(TInt aCommand);

public:
/**
  Initiates the searching of a word.
  @param aWord The word to search for.
  */
	void SearchWordL(const TDesC& aWord);

/**
  Displays the meaning of a word in the results view. It does so by calling
  the appropriate functions of Dict engine and activating the meaning view.
  @param aIndex The index of the word to be shown.
  */
	void ShowItemL(TInt aIndex);

private:
/**
  Displays a list of the available dictionaries. Allows the user
  to change the active dictionary.
  */
	void ShowDictionaryListL();

/**
   Displays Edit Path Dialog, which allows the user to change
   the path, where dictionary databases are located.
  */
	void ShowEditPathDialog();

private:
	/** A pointer to the Search View.*/
	CDictSearchView* iDictSearchView;

	/** A pointer to the Results List View.*/
	CDictResultsListView* iDictResultsListView;

	/** A pointer to the Meaning View.*/
	CDictMeaningView *iDictMeaningView;

	/** A pointer to the object that constructs and switches between
	    Dict Engine objects.*/
	CDictFactory *iDictFactory;

	/** List of the headwords matching the search criteria.*/
	CDesCArrayFlat* iHeadwordList;
#ifdef __SERIES60_30__					
	CDocumentHandler *iHandler;
#endif
	};


#endif // __DICT_APPUI_H__

