/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __DICT_RESULTS_LIST_CONTAINER_H__
#define __DICT_RESULTS_LIST_CONTAINER_H__

#include <aknview.h>
#include <aknlists.h>

class CDictResultsListView;

/**
  An instance of CDictSearchContainer contains the view drawn to
  the screen for CDictResultsListView.
*/
class CDictResultsListContainer : public CCoeControl
	{
public:
/**
  Constructor.
*/
	CDictResultsListContainer();

/**
  Destructor.
*/
	~CDictResultsListContainer();

/**
  Creates a CDictResultsListContainer object, which will draw itself
  to aRect.
  @param aRect The rectangle this view will be drawn to.
  @result A pointer to the created instance of CDictResultsListContainer.
  */
	static CDictResultsListContainer* NewL(const TRect& aRect);

/**
  Creates a CDictResultsListContainer object, which will draw itself
  to aRect.
  @param aRect The rectangle this view will be drawn to.
  @result A pointer to the created instance of CDictResultsListContainer.
  */
	static CDictResultsListContainer* NewLC(const TRect& aRect);

/**
  Performs the second phase construction of a CDictResultsListContainer
  object.
  @param aRect Frame rectangle for container.
  */
	void ConstructL(const TRect& aRect);

public: // from CoeControl
/**
  Returns the number of controls contained in this compound control.
  (from CoeControl)
  @result The number of controls.
  */
	TInt CountComponentControls() const;

/**
  Returns a pointer to the specified component. (from CoeControl)
  @param aIndex Specification for component pointer.
  @return Pointer to component control.
  */
	CCoeControl* ComponentControl(TInt aIndex) const;

/**
  Draws this CDictResultsListContainer to the screen. (from CoeControl)
  @param aRect The rectangle of this view that needs updating.
  */
	void Draw(const TRect& aRect) const;

/**
  Offers the key event to the list box. (from CoeControl)
  @param aKeyEvent The key that caused the event.
  @param aType the Type of event that occured.
  */
	TKeyResponse OfferKeyEventL(const TKeyEvent& aKeyEvent, TEventCode aType);

public:
/**
  Sets the list to be displayed by the list-box control.
  @param aList A pointer to the list.
  */
	void SetHeadwordList(CDesCArrayFlat* aList) {iHeadwordList = aList;};

/**
  Sets the parent view.
  @param aView A pointer to the parent view.
  */
	void SetParentView(CDictResultsListView *aView) {iParentView = aView;};

/**
  Sets the current selection of the list-box control.
  @param aSelection the number of the current selection.
  */
	void SetCurrentSelection(TInt aSelection);

	
#ifdef __SERIES60_30__
	void HandleResourceChange(TInt aType);
#endif
	
private:
/**
  Tests if the the list view is empty.
  @result ETrue if the list view contains entries.
  */
	TBool ContainsEntries();

	/** The control used to display the results.*/
	CEikTextListBox* iResultsListBox;

	/** The list of headwords to display.*/
	CDesCArrayFlat* iHeadwordList;

	/** A pointer to the view that owns the container.*/
	CDictResultsListView *iParentView;
	};

#endif // __DICT_RESULTS_LIST_CONTAINER_H__