/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __DICT_RESULTS_LIST_VIEW_H__
#define __DICT_RESULTS_LIST_VIEW_H__

#include <aknview.h>

class CDictResultsListContainer;

/**
  An instance of the Application View object for the Dict application.
  Contains a list-box control, that displays the headwords that match
  the search criteria.
*/
class CDictResultsListView: public CAknView
	{
public:

/**
  Creates a CDictResultsListView object.
  @result A pointer to the created instance of CDictResultsListView.
*/
	static CDictResultsListView* NewL();

/**
  Creates a CDictResultsListView object.
  @result A pointer to the created instance of CDictResultsListView.
*/
	static CDictResultsListView* NewLC();


/**
  Destructor.
*/
	~CDictResultsListView();


public: // from CAknView

/**
  Identity of this view to the system. (from CAknView)
  @result the ID of view.
*/
	TUid Id() const;

/**
  Handles a user command. (from CAknView)
  @param aCommand Command to be handled.
*/
	void HandleCommandL(TInt aCommand);

/**
  Creates the Container class object. (from CAknView)
  @param aPrevViewId The id of the previous view.
  @param aCustomMessageId Message identifier.
  @param aCustomMessage Custom message provided when the view is changed.
*/
  void DoActivateL(const TVwsViewId& aPrevViewId,
	               TUid aCustomMessageId,
	               const TDesC8& aCustomMessage);

/**
  Removes the container class instance from the App UI's stack and
  deletes the instance. (from CAknView)
*/
  void DoDeactivate();

private:

/**
  Performs the first phase of two phase construction.
*/
	CDictResultsListView();

/**
  Performs the second phase construction of a CDictResultsListView object.
*/
	void ConstructL();

public:
/**
  Sets the headword list.
  @param aList A pointer to the headword list.
*/
	void SetHeadwordList(CDesCArrayFlat* aList);

/**
  Notifies the AppUI object that the user has selected an item.
  @param aIndex The index of the selected item.
*/
	void ShowItemL(TInt aIndex);

private:
	/** Holds the current selection.*/
	TInt iCurrentSelection;

	/** A pointer to the headword list.*/
	CDesCArrayFlat* iHeadwordList;

	/** Container for this view.*/
	CDictResultsListContainer* iContainer;

	/** Identifier for this view.*/
	TUid iIdentifier;
	};


#endif // __DICT_RESULTS_LIST_VIEW_H__
