/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __DICT_SEARCH_CONTAINER_H__
#define __DICT_SEARCH_CONTAINER_H__

#include <aknview.h>

class CEikLabel;
class CEikEdwin;
class CDictSearchView;

/**
  An instance of CDictSearchContainer contains the view drawn to
  the screen for CDictSearchView.
*/
class CDictSearchContainer : public CCoeControl
	{
public:
/**
  Constructor.
*/
	CDictSearchContainer();

/**
  Destructor.
*/
	~CDictSearchContainer();

/**
  Creates a CDictSearchContainer object, which will draw itself to aRect.
  @param aRect The rectangle this view will be drawn to.
  @result A pointer to the created instance of CDictSearchContainer.
*/
	static CDictSearchContainer* NewL(const TRect& aRect);

/**
  Createas a CDictSearchContainer object, which will draw itself to aRect.
  @param aRect The rectangle this view will be drawn to.
  @result A pointer to the created instance of CDictSearchContainer.
*/
	static CDictSearchContainer* NewLC(const TRect& aRect);

/**
  Performs the second phase construction of a CDictSearchContainer object.
  @param aRect Frame rectangle for container.
*/
	void ConstructL(const TRect& aRect);

public: // from CoeControl
/**
  Returns the number of controls contained in this compound control.
  (from CoeControl)
  @result The number of controls.
*/
	TInt CountComponentControls() const;

/**
  Returns a pointer to the specified component. (from CoeControl)
  @param aIndex Specification for component pointer.
  @return Pointer to component control.
*/
	CCoeControl* ComponentControl(TInt aIndex) const;

/**
  Draws this CDictSearchContainer to the screen. (from CoeControl)
  @param aRect The rectangle of this view that needs updating.
*/
	void Draw(const TRect& aRect) const;

/**
  Offers the key event to the text-box control. (from CoeControl)
  @param aKeyEvent The key that caused the event.
  @param aType The type of event that occured.
  */
	TKeyResponse OfferKeyEventL(const TKeyEvent& aKeyEvent, TEventCode aType);

public:
/**
  Sets the text in the text-box control.
  @param aWord The text to display in the text-box control.
  */
	void SetWordToSearch(TDesC* aWord) {iWordToSearch = aWord;};

/**
  Sets the name of the active dictionary.
  @param aName The name of the dictionary.
  */
	void SetDictionaryName(TDesC* aName);
#ifdef __SERIES60_30__	
	void HandleResourceChange(TInt aType);
#endif
private:
	friend class CDictSearchView;

/**
  Gets the text written in the text-box control.
  @param aDes A reference to the text in the text-box control.
  */
	void GetWordToSearch(TDes& aDes);

private:
	/** A pointer to the word to search.*/
	TDesC* iWordToSearch;

	/** A pointer to the dictionary name.*/
	TDesC* iDictionaryName;

	/** Object for use as the search text-box control.*/
	CEikEdwin *iSearchTextEditor;

	/** Object for use as a static text control for dictionary name.*/
	CEikLabel *iLabelWindow;
	
	TPoint iSearchTextEditorPosition;
	TSize iSearchTextEditorSize;
	
	};

#endif // __DICT_SEARCH_CONTAINER_H__
