/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <e32std.h>
#include <aknquerydialog.h>
#include <aknnotewrappers.h>
#include <aknglobalnote.h>
#include <AknQueryDialog.h>
#include <documenthandler.h>
#include <apmstd.h>
#include <S60Dict.rsg>
#include "Dict.hrh"
#include "Dict.pan"
#include "DictAppUi.h"
#include "DictSearchView.h"
#include "DictResultsListView.h"
#include "DictMeaningView.h"

#include "DictEngine.h"
#include "DictFactory.h"

CDictAppUi::CDictAppUi()
{
	iDictFactory = NULL;
	iHeadwordList = NULL;
#ifdef __SERIES60_30__					
	iHandler = CDocumentHandler::NewL();
#endif
}

CDictAppUi::~CDictAppUi()
{
#ifdef __SERIES60_30__					
	delete iHandler;
#endif	
	delete iDictFactory;
	iDictFactory = NULL;

	if (iHeadwordList)
		iHeadwordList->Reset();

	delete iHeadwordList;
	iHeadwordList = NULL;
}

void CDictAppUi::ConstructL()
	{
	TInt leaveValue;
	TRAP(leaveValue, BaseConstructL(EAknEnableSkin));
	if (leaveValue)
	{
		User::Exit(KErrNoMemory);
	}

	iDictSearchView = CDictSearchView::NewLC();
	AddViewL(iDictSearchView);
	CleanupStack::Pop(iDictSearchView);

	iDictResultsListView = CDictResultsListView::NewLC();
	AddViewL(iDictResultsListView);
	CleanupStack::Pop(iDictResultsListView);

	iDictMeaningView = CDictMeaningView::NewLC();
	AddViewL(iDictMeaningView);
	CleanupStack::Pop(iDictMeaningView);

	SetDefaultViewL(*iDictSearchView);;

	iDictFactory = CDictFactory::NewL();
	CleanupStack::PushL(iDictFactory);
	iHeadwordList = new (ELeave) CDesCArrayFlat(10);
	CleanupStack::Pop(iDictFactory);

	if (iDictFactory->IsDictionaryPresent())
	{
		TDesC *name, *path;

		name = path = NULL;
		TInt currentDatabase = iDictFactory->GetCurrentDataBase();
		if (iDictFactory->GetDataBaseName(currentDatabase, &name, &path))
		{
			if (name)
			{
				iDictSearchView->SetDictionaryName(*name);
			}
		}
	}

	}

void CDictAppUi::HandleCommandL(TInt aCommand)
	{
	switch(aCommand)
	    {
	    case EEikCmdExit:
	    case EAknSoftkeyExit:
	        Exit();
	        break;
		case EChangeDictionaryCmd:
			ShowDictionaryListL();
			break;
		case EEditPathCmd:
			ShowEditPathDialog();
			break;
		case EHelpCmd:
		{
#ifdef __SERIES60_30__	
		TFileName fileName;
		fileName.Append(_L("c:\\system\\apps\\S60Dict\\dict_help.txt"));
		TDataType nullType;
		iHandler->OpenFileEmbeddedL(fileName, nullType);
 			
#else
			//in 3rd edition, this will cause the help to be immediately closed again
			CDocumentHandler* handler = CDocumentHandler::NewL(NULL);
			CleanupStack::PushL(handler);
			TFileName fileName;
			fileName.Append(_L("c:\\system\\apps\\S60Dict\\dict_help.txt"));
			TDataType nullType;
			handler->OpenFileEmbeddedL(fileName, nullType);
			CleanupStack::PopAndDestroy();
			
#endif			
			break;
		}
		case EAboutCmd:
		{
			TInt index(0);
			CAknListQueryDialog*
				dlg = new (ELeave) CAknListQueryDialog(&index );
			dlg->ExecuteLD(R_ABOUT_DIALOG);
			break;
		}
	    default:
	        Panic(EDictBasicUi);
	        break;
	    }
	}

void CDictAppUi::SearchWordL(const TDesC& aWord)
{
	if (iDictFactory != NULL && iDictFactory->IsDictionaryPresent())
	{
		iHeadwordList->Reset();

		iDictResultsListView->SetHeadwordList(iHeadwordList);
		ActivateLocalViewL(TUid::Uid(EDictResultsListViewId));

		CDictEngine *dictEngine = iDictFactory->GetCurrentEngine();
		if (!dictEngine)
			return;

		if (!dictEngine->FindWord(aWord))
		{
			TBuf<100> resourceString;
			CEikonEnv::Static()->ReadResource(resourceString,
											  R_WORD_NOT_FOUND_STRING);
			CAknGlobalNote* globalNote = CAknGlobalNote::NewL();
			CleanupStack::PushL(globalNote);
			globalNote->ShowNoteL(EAknGlobalInformationNote, resourceString);
			CleanupStack::PopAndDestroy();
		}
		TInt results = dictEngine->GetResultsCount();
		TBuf<200> word;
		for(TInt i=0; i<results;i++)
		{
			if (dictEngine->GetFoundHeadword(i, word))
			{
				HBufC* buffer = HBufC::NewL(word.Length()+1);

				buffer->Des().Append('\t');
				buffer->Des().Append(word);

				iHeadwordList->AppendL(*buffer);
				delete buffer;
			}
		}
	}
	else
	{
		TBuf<100> resourceString;
		CEikonEnv::Static()->ReadResource(resourceString,
										  R_NO_DICTIONARIES_FOUND_STRING);
		CAknWarningNote* warningNote;
		warningNote = new (ELeave) CAknWarningNote;
		warningNote->ExecuteLD(resourceString);
	}
}

void CDictAppUi::ShowItemL(TInt aIndex)
{
	if (aIndex >= 0 && aIndex < iHeadwordList->Count())
	{
		CDictEngine *dictEngine = iDictFactory->GetCurrentEngine();
		HBufC *meaningText = NULL;

		if (!dictEngine)
		{
			return;
		}

		TInt returnCode = dictEngine->GetMeaningTextL(aIndex, &meaningText);
		if (returnCode == CDictEngine::NO_ERROR)
		{
			ActivateLocalViewL(TUid::Uid(EDictMeaningViewId));
			iDictMeaningView->SetMeaningText(meaningText);
		}
		else
		{
			TBuf<100> resourceString;

			switch (returnCode)
			{
				case CDictEngine::ERROR_NOT_ENOUGH_MEMORY:
					CEikonEnv::Static()->ReadResource(resourceString,
											  R_NOT_ENOUGH_MEMORY_STRING);
					break;
				case CDictEngine::ERROR_CANT_READ_FROM_FILE:
					CEikonEnv::Static()->ReadResource(resourceString,
											  R_CANT_READ_FROM_FILE_STRING);
					break;
				case CDictEngine::ERROR_LENGTH_IS_ZERO:
					CEikonEnv::Static()->ReadResource(resourceString,
											  R_LENGTH_IS_ZERO_STRING);
					break;
				default:
				case CDictEngine::ERROR_ASSERT:
					CEikonEnv::Static()->ReadResource(resourceString,
											  R_INTERNAL_ERROR);
					break;
			}
			User::InfoPrint(resourceString);
		}
	}
}

void CDictAppUi::ShowDictionaryListL()
{
	TDesC *name, *path;
	TBuf<KDataBaseNameSizeMax> str;

	CDesCArray *itemTextArray = new (ELeave) CDesCArrayFlat(10);
	CleanupStack::PushL(itemTextArray);

	for(TInt i=0; i<iDictFactory->GetDataBaseCount(); i++)
	{
		name = path = NULL;
		if (iDictFactory->GetDataBaseName(i, &name, &path) && name)
		{
			str.Copy(*name);
		}
		else
		{
			TBuf<100> resourceString;
			CEikonEnv::Static()->ReadResource(resourceString,
											  R_CORRUPT_STRING);
			str.Copy(resourceString);
		}

		itemTextArray->AppendL(str);
	}

	TInt itemSelected(0), prevSelection;
	CAknListQueryDialog* listQuery = new (ELeave) CAknListQueryDialog(&itemSelected);
	listQuery->PrepareLC(R_DICTIONARY_LIST_DIALOG);
	listQuery->SetItemTextArray(itemTextArray);
	listQuery->SetOwnershipType(ELbmDoesNotOwnItemArray);

	prevSelection = iDictFactory->GetCurrentDataBase();
	if (prevSelection >= 0 && prevSelection < itemTextArray->Count())
	{
		listQuery->ListBox()->SetCurrentItemIndex(prevSelection);
	}
	if(listQuery->RunLD())
	{
		iDictFactory->SetCurrentDataBase(itemSelected);
		iDictSearchView->SetDictionaryName((*itemTextArray)[itemSelected]);
	}
	CleanupStack::PopAndDestroy();
}

void CDictAppUi::ShowEditPathDialog()
{
	TBuf<200> textData(NULL);
	iDictFactory->GetPath(textData, 200);
	CAknTextQueryDialog* dlg = new(ELeave) CAknTextQueryDialog(textData,
							CAknQueryDialog::ENoTone);
	if (dlg->ExecuteLD(R_PATH_EDIT_DIALOG))
	{
		iDictFactory->SetPath(textData);
    }
}