/*  This file is a part of Dict. Dict is a Series 60 application for browsing
	dict databases (http:\\www.dict.org) stored in the phone's file system.
	Copyright (C) 2005, Kostas Giannakakis
	Web page: http://users.forthnet.gr/ath/kgiannak/

	Dict is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Dict is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Dict; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <aknlists.h>
#if defined(__SYMBIAN_7__) || defined(__SERIES60_30__)	
#include <aknsskininstance.h> 
#include <aknscontrolcontext.h>
#include <aknsdrawutils.h> 
#include <aknutils.h> 
#endif

#include "DictResultsListContainer.h"
#include "DictResultsListView.h"
#include "Dict.pan"

CDictResultsListContainer::CDictResultsListContainer()
	{
	iResultsListBox = NULL;
	iHeadwordList = NULL;
	iParentView = NULL;
	}

CDictResultsListContainer::~CDictResultsListContainer()
	{
	delete iResultsListBox;
	iResultsListBox = NULL;
	}

CDictResultsListContainer* CDictResultsListContainer::NewL(const TRect& aRect)
	{
	CDictResultsListContainer* self = CDictResultsListContainer::NewLC(aRect);
	CleanupStack::Pop(self);
	return self;
	}

CDictResultsListContainer* CDictResultsListContainer::NewLC(const TRect& aRect)
	{
	CDictResultsListContainer* self = new (ELeave) CDictResultsListContainer;
	CleanupStack::PushL(self);
	self->ConstructL(aRect);
	return self;
	}

void CDictResultsListContainer::ConstructL(const TRect& aRect)
	{
	CreateWindowL();
	SetRect(aRect);

	// Create a control to display a list of messages
	iResultsListBox = new (ELeave) CAknSingleStyleListBox;
	iResultsListBox->SetContainerWindowL(*this);
	iResultsListBox->ConstructL(this, 0);

	iResultsListBox->SetRect(aRect.Size());

	iResultsListBox->ActivateL();
	iResultsListBox->CreateScrollBarFrameL(ETrue);
	iResultsListBox->ScrollBarFrame()->SetScrollBarVisibilityL(CEikScrollBarFrame::EOn,
															CEikScrollBarFrame::EAuto);
	if (iHeadwordList)
	{
		CTextListBoxModel* model = iResultsListBox->Model();
		model->SetItemTextArray(iHeadwordList);
		model->SetOwnershipType(ELbmDoesNotOwnItemArray);

		if (iHeadwordList->Count() > 0)
		{
			iResultsListBox->HandleItemAdditionL();
		}
	}

	ActivateL();
	}

TInt CDictResultsListContainer::CountComponentControls() const
	{
	return 1;
	}

void CDictResultsListContainer::Draw(const TRect& aRect) const
	{
	CWindowGc& gc = SystemGc();
	gc.SetPenStyle(CGraphicsContext::ENullPen);
	gc.SetBrushColor(KRgbWhite);
	gc.SetBrushStyle(CGraphicsContext::ESolidBrush);
	gc.DrawRect(aRect);
	}

CCoeControl* CDictResultsListContainer::ComponentControl(TInt aIndex) const
	{
		if (aIndex == 0)
			return iResultsListBox;
		Panic(EDictResultsListContainer);
		return NULL;
	}

TKeyResponse CDictResultsListContainer::OfferKeyEventL(const TKeyEvent& aKeyEvent,
													   TEventCode aType)
{
	// We only want the key press, not the key up/down event
	if (aType == EEventKey)
	{
		if (ContainsEntries() &&
			(aKeyEvent.iCode == EKeyEnter || aKeyEvent.iCode == EKeyDevice3))
		{
			TInt sel = iResultsListBox->CurrentItemIndex();
			if (iParentView)
			{
				iParentView->ShowItemL(sel);
			}
		}
	}

	// Return the default functionality
	return iResultsListBox->OfferKeyEventL(aKeyEvent, aType);
}

TBool CDictResultsListContainer::ContainsEntries()
	{
	return iResultsListBox->Model()->NumberOfItems() != 0;
	}


void CDictResultsListContainer::SetCurrentSelection(TInt aSelection)
{
	if (aSelection >= 0 &&
		aSelection < iResultsListBox->Model()->NumberOfItems())
	{
		iResultsListBox->SetCurrentItemIndexAndDraw(aSelection);
	}
}

#ifdef __SERIES60_30__
void  CDictResultsListContainer::HandleResourceChange(TInt aType)
{
	CCoeControl::HandleResourceChange(aType);
    if  ( aType == KEikDynamicLayoutVariantSwitch ) {
    	TRect rect;
    	AknLayoutUtils::LayoutMetricsRect(AknLayoutUtils::EMainPane, rect);
		SetRect(rect);
    }
}
#endif
